<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ms">
<context>
    <name>CanvasGridView</name>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3474"/>
        <source>Icon size</source>
        <translation>Saiz ikon</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3483"/>
        <source>Auto merge</source>
        <translation>Auto gabung</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3495"/>
        <source>Auto arrange</source>
        <translation>Auto susun</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3534"/>
        <source>Corner Settings</source>
        <translation>Tetapan Bucu</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3543"/>
        <location filename="../view/canvasgridview.cpp" line="3548"/>
        <source>Set Wallpaper</source>
        <translation>Tetapkan Kertas Dinding</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3546"/>
        <source>Wallpaper and Screensaver</source>
        <translation>Kertas Dinding dan Penyelamat Skrin</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3732"/>
        <source>Properties</source>
        <translation>Sifat</translation>
    </message>
    <message>
        <location filename="../view/canvasgridview.cpp" line="3524"/>
        <source>Display Settings</source>
        <translation>Tetapan Paparan</translation>
    </message>
</context>
<context>
    <name>DesktopItemDelegate</name>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="23"/>
        <source>Tiny</source>
        <translation>Sangat kecil</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="24"/>
        <source>Small</source>
        <translation>Kecil</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="25"/>
        <source>Medium</source>
        <translation>Sederhana</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="26"/>
        <source>Large</source>
        <translation>Besar</translation>
    </message>
    <message>
        <location filename="../view/desktopitemdelegate.cpp" line="27"/>
        <source>Super large</source>
        <translation>Sangat besar</translation>
    </message>
</context>
<context>
    <name>DesktopMain</name>
    <message>
        <location filename="../main.cpp" line="158"/>
        <source>Desktop</source>
        <translation>Atas Meja</translation>
    </message>
</context>
<context>
    <name>Frame</name>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="700"/>
        <source>Wallpaper Slideshow</source>
        <translation>Paparan Slaid Kertas Dinding</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="746"/>
        <source>When login</source>
        <translation>Bila daftar masuk</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="748"/>
        <source>When wakeup</source>
        <translation>Bila bangun</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="800"/>
        <source>Require a password on wakeup</source>
        <translation>Perlukan kata laluan ketika bangun</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="832"/>
        <source>Never</source>
        <translation>Tidak Sesekali</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="834"/>
        <source>Wait:</source>
        <translation>Tunggu:</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="867"/>
        <source>Wallpaper</source>
        <translation>Kertas Dinding</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="879"/>
        <source>Screensaver</source>
        <translation>Penyelamat Skrin</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="944"/>
        <source>Loading wallpapers...</source>
        <translation>Memuatkan kertas dinding...</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="946"/>
        <source>Loading screensavers...</source>
        <translation>Memuatkan penyelamat skrin...</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1004"/>
        <source>Desktop</source>
        <comment>button</comment>
        <translation>Atas Meja</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1005"/>
        <source>Lock Screen</source>
        <comment>button</comment>
        <translation>Kunci Skrin</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1006"/>
        <source>Both</source>
        <translation>Kedua-duanya</translation>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1094"/>
        <source>Custom Screensaver</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1095"/>
        <location filename="../../dde-wallpaper-chooser/frame.cpp" line="1097"/>
        <source>Apply</source>
        <comment>button</comment>
        <translation>Laksana</translation>
    </message>
</context>
<context>
    <name>WaterMaskFrame</name>
    <message>
        <location filename="../view/watermaskframe.cpp" line="127"/>
        <location filename="../view/watermaskframe.cpp" line="128"/>
        <source>Not authorized</source>
        <translation>Tidak dibenarkan</translation>
    </message>
    <message>
        <location filename="../view/watermaskframe.cpp" line="136"/>
        <location filename="../view/watermaskframe.cpp" line="137"/>
        <source>In trial period</source>
        <translation>Masih dalam percubaan</translation>
    </message>
</context>
</TS>